data rice20;
input
variety$ yield tillers;
plot=_N_;
datalines;
IR1514A 5932 7.98
IR1514A 4050 5.72
IR1514A 4164 4.95
IR1514A 4862 7.82
IR1514A 5596 6.67
IR1514A 5570 6.55
IR1514A 4002 5.28
IR8     4876 9.98
IR8     3267 7.67
IR8     2051 6.67
IR8     4322 8.33
IR8     4557 9.16
IR8     4832 9.67
IR8     2322 6.75
Peta    1528 7.90
Peta    2858 6.39
Peta    3857 5.78
Peta    3796 5.55
Peta    1507 6.50
Peta    2078 7.67
Peta    1638 7.03
;
proc corr data=rice20;
var tillers yield;
run;

proc reg data=rice20;
model tillers=yield;
run;

data rice2;
set rice20;
trait='yield'; y=yield/1000; output;
trait='tillers'; y=tillers; output;
run;

/*bivariate analysis*/

/*UNR*/
proc glimmix data=rice2 scoring=10 asycov;
class plot variety trait;
model y=trait;
random trait/sub=variety type=unr vcorr v;
random trait/sub=variety*plot type=unr residual;
run;

/*UNR*/
proc glimmix data=rice2 scoring=10 asycov;
class plot variety trait;
model y=trait;
random trait/sub=variety type=unr vcorr v;
random trait/sub=variety*plot type=unr residual group=variety;
run;

/*testing error correlations taking blocks and treatments as fixed*/
proc glimmix data=rice2 scoring=10 asycov;
class plot variety trait;
model y=trait trait*variety;
random trait/sub=variety*plot type=unr residual group=variety;
covtest 'heterogeneity of VCOV' general 1 0 0 -1 0 0  0 0 0,
                                        1 0 0  1 0 0 -2 0 0,
                                        0 1 0 0 -1 0 0  0 0,
                                        0 1 0 0  1 0 0 -2 0,
                                        0 0 1 0 0 -1 0 0  0,
                                        0 0 1 0 0  1 0 0 -2;
covtest 'error correlations=0' general 0 0 0 0 0 0 0 0 0 0 0 0,
                                      0 0 0 0 0 1 0 0 0 0 0 0,
                                      0 0 0 0 0 0 0 0 1 0 0 0,
                                      0 0 0 0 0 0 0 0 0 0 0 1;
run;

/*UN(1)*/
proc mixed data=rice2 scoring=10 asycov covtest;
class plot variety trait;
model y=trait;
random trait/sub=variety type=un(1) vcorr v;
repeated trait/sub=variety*plot type=un(1);
run;

data rice20;
set rice20;
yield2=yield/1000;
label variety='Variety';
run;

proc template;
  define style styles.mystyle;
  parent=styles.default;
    style GraphData1 from GraphData1 /
          markersymbol='circle'   linestyle=1 contrastcolor=green;
    style GraphData2 from GraphData2 /
          markersymbol='triangle' linestyle=2 contrastcolor=red;
    style GraphData3 from GraphData3 /
          markersymbol='diamond'  linestyle=3 contrastcolor=blue;
    style GraphData4 from GraphData4 /
          markersymbol='square'   linestyle=4 contrastcolor=orange;
    style graphbackground from graphbackground / 
color=_undef_;   end;
run;

ods listing GPATH='d:\hpp\veroeff\17\correlation\revision\Examples' image_dpi=600 style=styles.mystyle;
ods graphics on/ reset border=off outputfmt=gif 
    imagename="Figure9" width=4in height=4in ;
ods html style=styles.mystyle;
proc sgplot data=rice20;
reg y=yield2 x=tillers/group=variety markerattrs=(size=10);
yaxis label='Yield (t/ha)';
xaxis label='Number of tillers';
run;
